Axiom
=====

Axiom is a Python library and command-line utility for verifying metadata against a defined standard.

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   about
   installation
   cli

.. toctree::
   :maxdepth: 2
   :caption: Metadata
   
   metadata
   schemas/schemas
   conversion
   validation
   reporting
   
.. toctree::
   :maxdepth: 2
   :caption: Data Reference Syntax (DRS)
   
   drs/index
   drs/configuration
   drs/payloads
   drs/fault-tolerance
   drs/typical-workflow
   drs/custom_processors
   drs/performance

.. toctree::
   :maxdepth: 2
   :caption: For developers

   api
   qa
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
